@@ -1,9 +1,9 @@
 import os
 import pprint
 import subprocess
-import threading
-from shutil import move
-from typing import Callable
+import sys
+from traceback import format_exc
+from typing import List
 
 import papermill as pm  # type: ignore
 
@@ -17,24 +17,6 @@ global cancelled
 cancelled = False
 
 
-def set_interval(func: Callable, sec: int):
-    def func_wrapper():
-        if cancelled:
-            return
-        func()
-        set_interval(func, sec)
-
-    t = threading.Timer(sec, func_wrapper)
-    t.start()
-    return t
-
-
-def cancel_interval():
-    log("Cancelling Interval")
-    global cancelled
-    cancelled = True
-
-
 def save_artifacts():
     log(f"saving all artifacts")
 
@@ -53,8 +35,8 @@ def save_artifacts():
                 upload_artifact(full_name, upload_path)
 
 
-def run(project_id: str, notebook_id: str, run_id: str):
-    move(".treebeard", "/home/project_user/.treebeard")  # this may not be needed now...
+def run(project_id: str, notebook_id: str, run_id: str) -> List[str]:
+    log(f"🌲 treebeard runtime: running repo")
     subprocess.run(
         [
             "bash",
@@ -72,11 +54,12 @@ def run(project_id: str, notebook_id: str, run_id: str):
     for output_dir in treebeard_config.output_dirs:
         os.makedirs(output_dir, exist_ok=True)
 
-    set_interval(save_artifacts, 10)
-
     failed_notebooks = []
 
-    for notebook_path in treebeard_config.deglobbed_notebooks:
+    for i, notebook_path in enumerate(treebeard_config.deglobbed_notebooks):
+        print(
+            f"Running {i}/{len(treebeard_config.deglobbed_notebooks)}: {notebook_path}"
+        )
         try:
             notebook_dir, notebook_name = os.path.split(notebook_path)
             log(f"Executing Notebook {notebook_name} in {notebook_dir}")
@@ -90,20 +73,15 @@ def run(project_id: str, notebook_id: str, run_id: str):
                 log_output=True,
                 cwd=f"{os.getcwd()}/{notebook_dir}",
             )
-        except Exception as ex:
+        except Exception:
             failed_notebooks.append(notebook_path)
-            print(f"Run failed!")
-            raise ex
+            tb = format_exc()
+            print(f"Notebook {notebook_path} failed!\n{tb}")
 
-    cancel_interval()
     save_artifacts()
     log("Finished")
 
-    if len(failed_notebooks) > 0:
-        print(f"Flagging failed run!")
-        raise Exception(
-            f"One or more notebooks failed!\n{pp.pformat(failed_notebooks)}"
-        )
+    return failed_notebooks
 
 
 if __name__ == "__main__":
@@ -112,4 +90,10 @@ if __name__ == "__main__":
     if not treebeard_env.project_id:
         raise Exception("No project ID at buildtime")
 
-    run(treebeard_env.project_id, treebeard_env.notebook_id, treebeard_env.run_id)
+    failed_notebooks = run(
+        treebeard_env.project_id, treebeard_env.notebook_id, treebeard_env.run_id
+    )
+
+    if len(failed_notebooks) > 0:
+        print(f"One or more notebooks failed: {pp.pformat(failed_notebooks)}")
+        sys.exit(1)
